@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class TinymceFilebrowserConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'apps.tinymce_filebrowser'
+    name = 'tinymce_filebrowser'
